module Pluralizr

  # A TypeError meant to inform users when the object passed into the Pluralizr.pluralize method isn't a String.
  # For example, integers, boolean values, arrays, etc.

  class InvalidTypeError < TypeError
    def initialize(msg="argument must be a String")
      super
    end
  end

  # A TypeError meant to inform users when the object passed into the Pluralizr.pluralize method doesn't begin with a letter.
  # For example, words like +32numbersfirst+ and +.specialcharactersfirst+

  class InvalidStringError < TypeError
    def initialize(msg="string must begin with a letter")
      super
    end
  end

  # An ArgumentError meant to inform users when the object passed into the Pluralizr.pluralize method is a String, but contains more than one word.
  # For example, strings like <tt>"More than one word"</tt>.

  class TooManyWordsError < ArgumentError
    def initialize(msg="argument contains too many words")
      super
    end
  end
end
