module Pluralizr

  # Hash containing the various rules for specific word endings
  # in the English language.
  #--
  # These endings are stored in the hash as keys. Each key has a set
  # of properties as its value. These properties specify the word's
  # plural form ending, how the plural form should be applied to the
  # original word, and if there are any words considered exceptions
  # to the particular rule.
  #
  # For example, given a word that ends in 'a', the pluralize() method
  # will check for errors (see exceptions.rb) and special cases (see lists.rb),
  # and then iterate through the RULES hash below. Since the word ends in
  # 'a', it matches with the RULES['a'] key, and since this list contains an
  # exceptions list, it checks if the word is on the list. If so, it returns
  # the plural version of that word from the exceptions list. If not, it adds
  # an 's' to the end of the original word and returns it.

  RULES = {
    'ia'        =>  { with_ending: 's',    offset: -1 },
    'a'         =>  { with_ending: 's',    offset: -1, has_exception_list: true },
    'ffe'       =>  { with_ending: 's',    offset: -1 },
    'fe'        =>  { with_ending: 'ves',  offset: -3, has_exception_list: true },
    'ff'        =>  { with_ending: 's',    offset: -1 },
    'f'         =>  { with_ending: 'ves',  offset: -2, has_exception_list: true },
    'ch'        =>  { with_ending: 'es',   offset: -1, has_exception_list: true },
    'sh'        =>  { with_ending: 'es',   offset: -1, has_exception_list: true },
    'um'        =>  { with_ending: 'a',    offset: -3, has_exception_list: true },
    'tion'      =>  { with_ending: 's',    offset: -1 },
    'on'        =>  { with_ending: 's',    offset: -1, has_exception_list: true },
    'o'         =>  { with_ending: 'es',   offset: -1, has_exception_list: true },
    'is'        =>  { with_ending: 'es',   offset: -3 },
    'us'        =>  { with_ending: 'es',   offset: -1, has_exception_list: true },
    's'         =>  { with_ending: 'es',   offset: -1, has_exception_list: true },
    'eau'       =>  { with_ending: 's',    offset: -1 },
    'ex'        =>  { with_ending: 'ices', offset: -3, has_exception_list: true },
    'x'         =>  { with_ending: 'es',   offset: -1, has_exception_list: true },
    'y'         =>  { with_ending: 'ies',  offset: -2 },
    'z'         =>  { with_ending: 'es',   offset: -1, has_exception_list: true },
    'irregular' =>  {                      offset: -1, has_exception_list: true },
    'default'   =>  { with_ending: 's',    offset: -1 }
  }

end
